@@ -15,10 +15,10 @@ import           Data.Text.PgpWordlist
 import           Data.Word
 import           System.Timeout        (timeout)
 
-import           Data.Text.Prettyprint.Doc
-import           Data.Text.Prettyprint.Doc.Internal.Debug
-import           Data.Text.Prettyprint.Doc.Render.Text
-import           Data.Text.Prettyprint.Doc.Render.Util.StackMachine (renderSimplyDecorated)
+import           Prettyprinter
+import           Prettyprinter.Internal.Debug
+import           Prettyprinter.Render.Text
+import           Prettyprinter.Render.Util.StackMachine (renderSimplyDecorated)
 
 import Test.QuickCheck.Instances.Text ()
 import Test.Tasty
@@ -88,6 +88,10 @@ tests = testGroup "Tests"
             [ testCase "Line" regressionUnboundedGroupedLine
             , testCase "Line within align" regressionUnboundedGroupedLineWithinAlign
             ]
+        , testCase "Indentation on otherwise empty lines results in trailing whitespace (#139)"
+                   indentationShouldntCauseTrailingWhitespaceOnOtherwiseEmptyLines
+        , testCase "Ribbon width should be computed with `floor` instead of `round` (#157)"
+                   computeRibbonWidthWithFloor
         ]
     ]
 
@@ -380,3 +384,19 @@ regressionUnboundedGroupedLineWithinAlign
         sdoc = layoutPretty (LayoutOptions Unbounded) doc
         expected = SChar 'x' (SLine 0 (SChar 'y' SEmpty))
     in assertEqual "" expected sdoc
+
+indentationShouldntCauseTrailingWhitespaceOnOtherwiseEmptyLines :: Assertion
+indentationShouldntCauseTrailingWhitespaceOnOtherwiseEmptyLines
+  = let doc :: Doc ()
+        doc = indent 1 ("x" <> hardline <> hardline <> "y" <> hardline)
+        sdoc = layoutPretty (LayoutOptions Unbounded) doc
+        expected = SChar ' ' (SChar 'x' (SLine 0 (SLine 1 (SChar 'y' (SLine 0 SEmpty)))))
+    in assertEqual "" expected sdoc
+
+computeRibbonWidthWithFloor :: Assertion
+computeRibbonWidthWithFloor
+  = let doc :: Doc ()
+        doc = "a" <> softline' <> "b"
+        sdoc = layoutPretty (LayoutOptions (AvailablePerLine 3 0.5)) doc
+        expected = SChar 'a' (SLine 0 (SChar 'b' SEmpty))
+    in assertEqual "" expected sdoc
